//    Austin is a program for updating projects kept in XML files.
//    Copyright (C) 2000  Joseph Gregorio
//
//    This program is free software; you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation; either version 2 of the License, or
//    (at your option) any later version.
//
//    This program is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with this program; if not, write to the Free Software
//    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

#pragma warning(disable:4786)

#include "Duration.h"
#include <sstream>
using namespace std;

const int conversionFactor[] = {
	1,
	7,
	30,
	365
};


const wchar_t * shortLabelSingular[] = {
	L" D",
	L" W",
	L" M",
	L" Y"
};

const wchar_t * labelSingular[] = {
	L" Day",
	L" Week",
	L" Month",
	L" Year"
};


const wchar_t * labelPlural[] = {
	L" Days",
	L" Weeks",
	L" Months",
	L" Years"
};


Duration::Duration() : days_(0), format_(DAY) {
}

Duration::Duration(const Duration& rhs) {
	days_ = rhs.days_;
	format_ = rhs.format_;
}

Duration::~Duration() {
}

Duration & Duration::operator=(const Duration & rhs) {
	days_ = rhs.days_;
	format_ = rhs.format_;
	
	return *this;
}

Duration::operator int () {
	return days_;
}

void Duration::set(const wstring & value) {
	wstringstream s(value);
	wstring label;

	s >> days_;
	s >> label;
	format_ = DAY;
	if (label.size() > 0) {
		wchar_t l = label[0];
		if (l == L'D' || l == L'd') {
			format_ = DAY;
		} else if (l == L'W' || l == L'w') {
			format_ = WEEK;
		} else if (l == L'M' || l == L'm') {
			format_ = MONTH;
		} else if (l == L'Y' || l == L'y') {
			format_ = YEAR;
		}
	}
	days_ = days_ * conversionFactor[format_];
}

void Duration::set(int value) {
	days_ = value;
}


wstring Duration::get() {
	wstringstream s;
	s << days_/conversionFactor[format_];
	if (1 == days_/conversionFactor[format_]) {	
		s << labelSingular[format_];
	} else {
		s << labelPlural[format_];
	}
	
	return s.str();
}

wstring Duration::getShortString() {
	wstringstream s;

	if (days_ > 0) {
		s << days_/conversionFactor[format_];
		s << shortLabelSingular[format_];
	}
	return s.str();
}



